/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.event;

/**
 * Adapter for the listener interface for Knowledge base events.  Subclass this class if you want only to catch a few
 * knowledge base events.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public abstract class KnowledgeBaseAdapter implements KnowledgeBaseListener {

    public void clsCreated(KnowledgeBaseEvent event) {
    }

    public void clsDeleted(KnowledgeBaseEvent event) {
    }

    public void defaultClsMetaClsChanged(KnowledgeBaseEvent event) {
    }

    public void defaultFacetMetaClsChanged(KnowledgeBaseEvent event) {
    }

    public void defaultSlotMetaClsChanged(KnowledgeBaseEvent event) {
    }

    public void facetCreated(KnowledgeBaseEvent event) {
    }

    public void facetDeleted(KnowledgeBaseEvent event) {
    }

    /*
     * @deprecated Override replaceFrame instead
     */
    @Deprecated
    public void frameNameChanged(KnowledgeBaseEvent event) {
        frameReplaced(event);
    }
    
    public void frameReplaced(KnowledgeBaseEvent event) {
    }

    public void instanceCreated(KnowledgeBaseEvent event) {
    }

    public void instanceDeleted(KnowledgeBaseEvent event) {
    }

    public void slotCreated(KnowledgeBaseEvent event) {
    }

    public void slotDeleted(KnowledgeBaseEvent event) {
    }
}
