/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model.framestore.undo;

import java.util.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.model.framestore.*;

class SetDirectOwnSlotValuesCommand extends AbstractCommand {
    private Collection values;
    private Slot slot;
    private Frame frame;
    private List _oldValues;

    SetDirectOwnSlotValuesCommand(FrameStore delegate, Collection values, Slot slot, Frame frame) {
        super(delegate);
        this.values = new ArrayList(values);
        this.slot = slot;
        this.frame = frame;
        setDescription("Set own slot " + getText(slot) + " at frame " + getText(frame) + " to {" + getText(values)
                + "}");
    }

    public Object doIt() {
        _oldValues = getDelegate().getDirectOwnSlotValues(frame, slot);
        getDelegate().setDirectOwnSlotValues(frame, slot, values);
        return null;
    }

    public void undoIt() {
        getDelegate().setDirectOwnSlotValues(frame, slot, _oldValues);
    }

    public void redoIt() {
        getDelegate().setDirectOwnSlotValues(frame, slot, values);
    }
}