/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.framestore;

import java.lang.reflect.Method;
import java.util.Collection;
import java.util.HashSet;

import edu.stanford.smi.protege.exception.ModificationException;
import edu.stanford.smi.protege.model.framestore.AbstractFrameStoreInvocationHandler;
import edu.stanford.smi.protege.model.query.Query;
import edu.stanford.smi.protege.model.query.QueryCallback;
import edu.stanford.smi.protege.server.RemoteSession;
import edu.stanford.smi.protege.server.Server;
import edu.stanford.smi.protege.server.metaproject.MetaProject;
import edu.stanford.smi.protege.server.metaproject.MetaProjectConstants;
import edu.stanford.smi.protege.server.metaproject.Policy;
import edu.stanford.smi.protege.server.metaproject.ProjectInstance;
import edu.stanford.smi.protege.server.metaproject.User;

public class ReadAccessEnforcementFrameStore extends AbstractFrameStoreInvocationHandler {
    private ServerFrameStore serverFrameStore;
    private Collection<String> readOnlyUsers = new HashSet<String>();
    
    public ReadAccessEnforcementFrameStore(ServerFrameStore serverFrameStore) {
        this.serverFrameStore = serverFrameStore;
        loadPolicy();
    }

    public void loadPolicy() {
        MetaProject metaproject = Server.getInstance().getMetaProjectNew();
        Policy policy = Server.getPolicy();
        ProjectInstance project = serverFrameStore.getMetaProjectInstance();
        
        readOnlyUsers.clear();
        for (User user : metaproject.getUsers()) {
            if (!policy.isOperationAuthorized(user, MetaProjectConstants.OPERATION_WRITE, project)) {
                readOnlyUsers.add(user.getName());
            }
        }
    }
    
    public boolean isApplicable() {
        return !readOnlyUsers.isEmpty();
    }
    
    public Object handleInvoke(Method method, Object[] args) {
        RemoteSession session = ServerFrameStore.getCurrentSession();
        boolean readOnly = readOnlyUsers.contains(session.getUserName());
        if (readOnly && method.getName().endsWith("Transaction")) {
            return Boolean.TRUE;
        }
        else if (readOnly && isModification(method)) {
            throw new ModificationException(method.getName());
        }
        else {
            return invoke(method, args);
        }
    }
    
    public void executeQuery(Query q, QueryCallback qc) {
      getDelegate().executeQuery(q, qc);
    }
}