/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.socket;

import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.logging.Level;
import java.util.logging.Logger;

import edu.stanford.smi.protege.server.ServerProperties;
import edu.stanford.smi.protege.util.Log;

public class SimulateDelayOutputStream extends FilterOutputStream {
    static Logger log = Log.getLogger(SimulateDelayOutputStream.class);
    private static int KB = MonitoringAspect.KB;
    
    private OutputStream os;
    
    private int bandwidth = ServerProperties.getKiloBytesPerSecondUpload();
    
    private int bytesWritten = 0;

    public SimulateDelayOutputStream(OutputStream os) {
        super(os);
        this.os = os;
    }
    
    @Override
    public void write(int b) throws IOException {
        os.write(b);
        delayForDownLoad(1);
    }
    
    @Override
    public void write(byte[] b, int off, int len) throws IOException {
        os.write(b, off, len);
        delayForDownLoad(len);
    }

    
    private synchronized void delayForDownLoad(int n) {
        bytesWritten += n;
        
        if (bandwidth != 0) {
            int secondsDelay = bytesWritten / (bandwidth * KB);
            if (secondsDelay > 0) {
                bytesWritten -= secondsDelay * bandwidth * KB;
                try {
                    Thread.sleep(1000 * secondsDelay);
                    log.info("Simulated " + secondsDelay + " seconds of download delay");
                } catch (InterruptedException e) {
                    log.log(Level.WARNING, "Simulation of network delay failed", e);
                }
            }
        }
    }
}
