/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.update;

import edu.stanford.smi.protege.model.Facet;
import edu.stanford.smi.protege.model.Frame;
import edu.stanford.smi.protege.model.KnowledgeBase;
import edu.stanford.smi.protege.model.Localizable;
import edu.stanford.smi.protege.model.Slot;
import edu.stanford.smi.protege.util.LocalizeUtils;

public class SftUpdate extends ValueUpdate implements Localizable {
  private static final long serialVersionUID = 8969314633657333324L;
  private Slot slot;
  private Facet facet;
  private boolean isTemplate;

  public SftUpdate(Frame frame, Slot slot, Facet facet, boolean isTemplate) {
    super(frame);
    this.slot = slot;
    this.facet = facet;
    this.isTemplate = isTemplate;
  }
  
  public Facet getFacet() {
    return facet;
  }
  
  public boolean isTemplate() {
    return isTemplate;
  }

  public Slot getSlot() {
    return slot;
  }
  
  public void localize(KnowledgeBase kb) {
    super.localize(kb);
    LocalizeUtils.localize(slot, kb);
    LocalizeUtils.localize(facet, kb);
  }

  @Override
  public ValueUpdate getInvalidatingVariant() {
    return new InvalidateCacheUpdate(getFrame(), slot, facet, isTemplate);
  }
  
  public String toString() {
    return "[" + super.toString() + ", " + slot.getFrameID() + ", " 
              + (facet == null ? "null" : "" + facet.getFrameID()) + ", " + isTemplate + "]";
  }
  

}
