/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.update;

import java.io.Serializable;

import edu.stanford.smi.protege.model.Frame;
import edu.stanford.smi.protege.model.KnowledgeBase;
import edu.stanford.smi.protege.model.Localizable;
import edu.stanford.smi.protege.server.RemoteSession;
import edu.stanford.smi.protege.util.LocalizeUtils;

public abstract class ValueUpdate implements Localizable, Serializable {
  private final static long serialVersionUID = -4059275656078639103L;
  private Frame frame;
  private transient RemoteSession client;
  private boolean transactionScope = false;
  
  public ValueUpdate(Frame frame) {
    this.frame = frame;
  }
  
  public Frame getFrame() {
    return frame;
  }

  public RemoteSession getClient() {
    return client;
  }

  public void setClient(RemoteSession client) {
    this.client = client;
  }

  public void localize(KnowledgeBase kb) {
    LocalizeUtils.localize(frame, kb);
  }
  
  public boolean isTransactionScope() {
    return transactionScope;
  }

  public void setTransactionScope(boolean transactionScope) {
    this.transactionScope = transactionScope;
  }
  
  public abstract ValueUpdate getInvalidatingVariant();
  
  public String toString() {
    return "ValueUpdate[" + frame.getFrameID() + ", Client = " + client + ", Transaction(" + transactionScope + ")]";
  }


}
