/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.ui;

import java.util.ArrayList;
import java.util.List;

import javax.swing.JList;
import javax.swing.ListModel;

import edu.stanford.smi.protege.model.Frame;
import edu.stanford.smi.protege.resource.ResourceKey;
import edu.stanford.smi.protege.util.FrameWithBrowserText;
import edu.stanford.smi.protege.util.SimpleStringMatcher;
import edu.stanford.smi.protege.util.StringMatcher;

public class BrowserTextListFinder extends ListFinder {

	private static final long serialVersionUID = 3317904008378472274L;
	
	public BrowserTextListFinder(JList list, ResourceKey key) {
		super(list, key);	
	}

	 protected List getMatches(String text, int maxMatches) {
	        if (!text.endsWith("*")) {
	            text += "*";
	        }

	        StringMatcher matcher = new SimpleStringMatcher(text);
	        List matchingInstances = new ArrayList();
	        ListModel model = _list.getModel();
	        int size = model.getSize();
	        for (int i = 0; i < size; ++i) {
	            FrameWithBrowserText fbt = (FrameWithBrowserText) model.getElementAt(i);
	            String browserText = fbt.getBrowserText();	            
	            if (browserText != null) {      	
	            	browserText = browserText.toLowerCase();
	            	if (matcher.isMatch(browserText)) {
	            		matchingInstances.add(fbt.getFrame());
	            	}
	            }
	        }
	        return matchingInstances;
	    }
	 
	 
	 protected void select(Object o) {
		 if (o instanceof Frame) {
			 _list.setSelectedValue(new FrameWithBrowserText((Frame)o), true);
		 } else if (o instanceof FrameWithBrowserText) {			 
			 _list.setSelectedValue(o, true);
		 } else {
			 _list.setSelectedIndex(0);
		 }
	 }
}
