/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import java.lang.ref.Reference;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.SoftReference;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.WeakHashMap;

/**
 * @author Ray Fergerson
 *
 * Description of this class
 */
public class CacheMap<X,Y>  extends WeakHashMap<X,Y> {
    private static final int INIT_SIZE = 10007;
    private int maxSize;

    public CacheMap(int maxSize) {
        super();
        this.maxSize = maxSize;
    }
    
    public CacheMap() {
        this(Integer.MAX_VALUE);
    }



    public Y put(X key, Y value) {
        Y oldValue = super.put(key, value);
        fixSize();
        return oldValue;
    }
    
    private void fixSize() {
        if (size() > maxSize) {
            Log.getLogger().info("removing elements from call cache");
            int count = 0;
            int nremove = maxSize/5;
            Iterator<X> i = keySet().iterator();
            while (i.hasNext() && count++ < nremove) {
                i.next();
                i.remove();
            }
        }
    }

}
