/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util.transaction.cache;

import java.io.Serializable;

public class CacheResult<R> implements Serializable {
    private R result;
    private boolean isValid;
    
    public CacheResult(R result, boolean isValid) {
        super();
        this.result = result;
        this.isValid = isValid;
    }
    
    public static <R> CacheResult<R> getInvalid() {
    	return new CacheResult<R>(null, false);
    }

    /**
     * @return the result
     */
    public R getResult() {
        return result;
    }

    /**
     * @return the isValid
     */
    public boolean isValid() {
        return isValid;
    }
    
    @SuppressWarnings("unchecked")
    @Override
    public boolean equals(Object obj) {
        if (!(obj instanceof CacheResult)) {
            return false;
        }
        CacheResult other = (CacheResult) obj;
        if (other.isValid() != isValid) {
            return false;
        }
        if (result == null) {
            return other.getResult() == null;
        }
        return result.equals(other.getResult());
    }
    
    @Override
    public int hashCode() {
        return result.hashCode() + (isValid ? 42 : 0);
    }
    
    public String toString() {
    	if (isValid()) {
        	StringBuffer sb = new StringBuffer("[");
        	sb.append("Valid Result ");
        	if (getResult() == null) {
        	    sb.append("null");
        	}
        	else {
        	    sb.append(" of type ");
        	    sb.append(getResult().getClass());
        	}
    		sb.append("]");
    		return sb.toString();
    	}
    	else {
    		return "[Invalid Result]";
    	}
    }

}
